==> vue-layout-builder-0.0.9.tgz: package/tests/mocks/state.js <==
export default {
  saveUrl: "foo",
  iframeSrc: null,
  sections: [
    {
      id: 1,
      layout: "LayoutThreeColumns",
      content: {}
    },
    {
      id: 2,
      layout: "LayoutTwoColumns",
      content: {
        1: [7, null, 8]
      }
    },
    {
      id: 3,
      layout: null,
      content: {}
    },
    {
      id: 4,
      layout: "LayoutTwoColumns",
      content: {
        1: [8],
        2: [8, 9]
      }
    }
  ],
  content_types: [
    {
      id: 1,
      name: "Documentation Center",
      group: "Foo group",
      url: "test.html"
    },
    {
      id: 2,
      name: "Media Player",
      group: "Bar group",
      url: "test.html"
    },
    {
      id: 3,
      name: "PDF",
      group: "Bar group",
      url: "test.html"
    }
  ],
  elements: {
    7: {
      html: '<div class="Element">documentation center</div>',
      editUrl: "foo?edit=7"
    },
    8: {
      html: '<div class="Element">media player</div>',
      editUrl: "foo?edit=8"
    },
    9: {
      html: '<div class="Element">pdf</div>',
      editUrl: "foo?edit=9"
    }
  },
  layouts: {
    LayoutOneColumn: {
      slots: ["1"],
      html:
        "<div class='Row'><div class='Column'><slot name='1'></slot></div></div>",
      name: "One column"
    },
    LayoutThreeColumns: {
      slots: ["1", "2", "3"],
      html:
        "<div class='Row'><div class='Column'><slot name='1'></slot></div><div class='Column'><slot name='2'></slot></div><div class='Column'><slot name='3'></slot></div></div>",
      name: "Three columns"
    },
    LayoutTwoColumns: {
      slots: ["1", "2"],
      html:
        "<div class='Row'><div class='Column'><slot name='1'></slot></div><div class='Column'><slot name='2'></slot></div></div>",
      name: "Two columns"
    }
  }
};

==> vue-layout-builder-0.0.12.tgz: package/tests/mocks/state.js <==
export default {
  saveUrl: "foo",
  iframeSrc: null,
  sections: [
    {
      id: 1,
      layout: "LayoutThreeColumns",
      content: {}
    },
    {
      id: 2,
      layout: "LayoutTwoColumns",
      content: {
        1: ["element7", null, "element8"]
      }
    },
    {
      id: 3,
      layout: null,
      content: {}
    },
    {
      id: 4,
      layout: "LayoutTwoColumns",
      content: {
        1: ["element8"],
        2: ["element8", "element9"]
      }
    }
  ],
  content_types: [
    {
      id: 1,
      name: "Documentation Center",
      group: "Foo group",
      url: "test.html"
    },
    {
      id: 2,
      name: "Media Player",
      group: "Bar group",
      url: "test.html"
    },
    {
      id: 3,
      name: "PDF",
      group: "Bar group",
      url: "test.html"
    }
  ],
  elements: {
    element7: {
      html: '<div class="Element">documentation center</div>',
      editUrl: "foo?edit=7",
      content_type_group: "Foo group",
      name: "Docu center"
    },
    element8: {
      html: '<div class="Element">media player</div>',
      editUrl: "foo?edit=8",
      content_type_group: "Bar group",
      name: "Media player"
    },
    element9: {
      html: '<div class="Element">pdf</div>',
      editUrl: "foo?edit=9",
      content_type_group: "Bar group",
      name: "Pdf"
    }
  },
  layouts: {
    LayoutOneColumn: {
      slots: ["1"],
      html:
        "<div class='Row'><div class='Column'><slot name='1'></slot></div></div>",
      name: "One column"
    },
    LayoutThreeColumns: {
      slots: ["1", "2", "3"],
      html:
        "<div class='Row'><div class='Column'><slot name='1'></slot></div><div class='Column'><slot name='2'></slot></div><div class='Column'><slot name='3'></slot></div></div>",
      name: "Three columns"
    },
    LayoutTwoColumns: {
      slots: ["1", "2"],
      html:
        "<div class='Row'><div class='Column'><slot name='1'></slot></div><div class='Column'><slot name='2'></slot></div></div>",
      name: "Two columns"
    }
  }
};
